==> openshift-model-monitoring-5.12.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/MatcherBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Object;
import java.lang.Boolean;
public class MatcherBuilder extends io.fabric8.openshift.api.model.monitoring.v1alpha1.MatcherFluentImpl<io.fabric8.openshift.api.model.monitoring.v1alpha1.MatcherBuilder> implements io.fabric8.kubernetes.api.builder.VisitableBuilder<io.fabric8.openshift.api.model.monitoring.v1alpha1.Matcher,io.fabric8.openshift.api.model.monitoring.v1alpha1.MatcherBuilder>{
  public MatcherBuilder() {
    this(false);
  }
  public MatcherBuilder(java.lang.Boolean validationEnabled) {
    this(new Matcher(), validationEnabled);
  }
  public MatcherBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.MatcherFluent<?> fluent) {
    this(fluent, false);
  }
  public MatcherBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.MatcherFluent<?> fluent,java.lang.Boolean validationEnabled) {
    this(fluent, new Matcher(), validationEnabled);
  }
  public MatcherBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.MatcherFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1alpha1.Matcher instance) {
    this(fluent, instance, false);
  }
  public MatcherBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.MatcherFluent<?> fluent,io.fabric8.openshift.api.model.monitoring.v1alpha1.Matcher instance,java.lang.Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withName(instance.getName()); 
    fluent.withRegex(instance.getRegex()); 
    fluent.withValue(instance.getValue()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MatcherBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.Matcher instance) {
    this(instance,false);
  }
  public MatcherBuilder(io.fabric8.openshift.api.model.monitoring.v1alpha1.Matcher instance,java.lang.Boolean validationEnabled) {
    this.fluent = this; 
    this.withName(instance.getName()); 
    this.withRegex(instance.getRegex()); 
    this.withValue(instance.getValue()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  io.fabric8.openshift.api.model.monitoring.v1alpha1.MatcherFluent<?> fluent;
  java.lang.Boolean validationEnabled;
  public io.fabric8.openshift.api.model.monitoring.v1alpha1.Matcher build() {
    Matcher buildable = new Matcher(fluent.getName(),fluent.getRegex(),fluent.getValue());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  public boolean equals(java.lang.Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    MatcherBuilder that = (MatcherBuilder) o;
    if (fluent != null &&fluent != this ? !fluent.equals(that.fluent) :that.fluent != null &&fluent != this ) return false;

    if (validationEnabled != null ? !validationEnabled.equals(that.validationEnabled) :that.validationEnabled != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(fluent,  validationEnabled,  super.hashCode());
  }
  
}

==> openshift-model-monitoring-6.1.1-sources.jar: io/fabric8/openshift/api/model/monitoring/v1alpha1/MatcherBuilder.java <==
package io.fabric8.openshift.api.model.monitoring.v1alpha1;

import io.fabric8.kubernetes.api.builder.VisitableBuilder;
import java.lang.Boolean;
public class MatcherBuilder extends MatcherFluentImpl<MatcherBuilder> implements VisitableBuilder<Matcher,MatcherBuilder>{
  public MatcherBuilder() {
    this(false);
  }
  public MatcherBuilder(Boolean validationEnabled) {
    this(new Matcher(), validationEnabled);
  }
  public MatcherBuilder(MatcherFluent<?> fluent) {
    this(fluent, false);
  }
  public MatcherBuilder(MatcherFluent<?> fluent,Boolean validationEnabled) {
    this(fluent, new Matcher(), validationEnabled);
  }
  public MatcherBuilder(MatcherFluent<?> fluent,Matcher instance) {
    this(fluent, instance, false);
  }
  public MatcherBuilder(MatcherFluent<?> fluent,Matcher instance,Boolean validationEnabled) {
    this.fluent = fluent; 
    fluent.withName(instance.getName()); 
    fluent.withRegex(instance.getRegex()); 
    fluent.withValue(instance.getValue()); 
    fluent.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  public MatcherBuilder(Matcher instance) {
    this(instance,false);
  }
  public MatcherBuilder(Matcher instance,Boolean validationEnabled) {
    this.fluent = this; 
    this.withName(instance.getName()); 
    this.withRegex(instance.getRegex()); 
    this.withValue(instance.getValue()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

    this.validationEnabled = validationEnabled; 
  }
  MatcherFluent<?> fluent;
  Boolean validationEnabled;
  public Matcher build() {
    Matcher buildable = new Matcher(fluent.getName(),fluent.getRegex(),fluent.getValue());
    buildable.setAdditionalProperties(fluent.getAdditionalProperties());
    return buildable;
  }
  
}
